<?php

if (!defined('_PS_VERSION_')) {
    exit;
}

class BlockLoginRegister extends Module
{
    public function __construct()
    {
        $this->name = 'blockloginregister';
        $this->tab = 'front_office_features';
        $this->version = '2.0.0';
        $this->author = 'kik-off';
        $this->need_instance = 0;
        $this->bootstrap = true;

        parent::__construct();

        $this->page = basename(__FILE__, '.php');
        $this->displayName = $this->l('User Login & Register');
        $this->description = $this->l('Popup for registration/Login');
    }

    public function install()
    {
        if (!parent::install() or
            !Configuration::updateValue('BL_AJAX_LOGIN', 0) or
            !$this->registerHook('displayNav') or
            !$this->registerHook('displayHeader')) {
            return false;
        }

        return true;
    }

    public function uninstall()
    {
        if (!parent::uninstall() or
            //!Configuration::deleteByName('BL_AJAX_LOGIN') or
            !$this->unregisterHook('displayNav') or
            !$this->unregisterHook('displayHeader') or
            !$this->unregisterHook('displayMyAccountBlock')) {
            return false;
        }

        return true;
    }

    public function getContent()
    {
        $this->_html = '';

        if (Tools::isSubmit('submitLoginRegister')) {
            $bl_ajax_login = Tools::getValue('bl_ajax_login');

            if (Configuration::updateValue('BL_AJAX_LOGIN', $bl_ajax_login)) {
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules').'&configure='.$this->name.'&tab_module='.$this->tab.'&conf=4&module_name='.$this->name);
            }
        }

        $helper = $this->renderForm();
        $helper->fields_value['bl_ajax_login'] = (int) Configuration::get('BL_AJAX_LOGIN');
        $this->_html .= $helper->generateForm($this->fields_form);
        
        return $this->_html;
    }

    public function renderForm()
    {
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

        $this->fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->displayName,
                'icon' => 'icon-users'
            ),
            'input' => array(
                array(
                    'type' => 'switch',
                    'label' => $this->l('Redirect to Account?'),
                    'name' => 'bl_ajax_login',
                    'is_bool' => true,
                    'hint' => $this->l('If disabled, it will remain on the same page where logs on'),
                    'values' => array(
                        array(
                            'id' => 'bl_ajax_login_on',
                            'value' => 1,
                            'label' => $this->l('Enabled'),
                        ),
                        array(
                            'id' => 'bl_ajax_login_off',
                            'value' => 0,
                            'label' => $this->l('Disabled'),
                        )
                    )
                )
            ),
            'submit' => array(
                'title' => $this->l('Save')
            ),
        );

        $helper = new HelperForm();
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;
        $helper->show_toolbar = false;
        $helper->submit_action = 'submitLoginRegister';

        return $helper;
    }

    public function hookDisplayNav($params)
    {
        if ($this->context->customer->isLogged()) {
            $has_address = $this->context->customer->getAddresses((int) $this->context->language->id);
            $this->context->smarty->assign(array(
                'has_customer_an_address' => empty($has_address),
                'voucherAllowed' => CartRule::isFeatureActive(),
                'returnAllowed' => (int) Configuration::get('PS_ORDER_RETURN'),
                'HOOK_BLR_MY_ACCOUNT' => Hook::exec('myaccountblock'),
            ));
            
            return $this->display(__FILE__, $this->name.'-my-account.tpl');
        } else {
            $this->context->smarty->assign(array(
                'bl_ajax_login' => (int) Configuration::get('BL_AJAX_LOGIN'),
                'is_rtl' => $this->context->language->is_rtl
            ));

            return $this->display(__FILE__, $this->name.'.tpl');
        }
    }

    public function hookDisplayHeader($params)
    {
        $this->context->controller->addCSS(($this->_path).'css/loginregister.css', 'all');
        
        if (!$this->context->customer->isLogged()) {
            Media::addJSDef(array('bl_ajax_login' => (int) Configuration::get('BL_AJAX_LOGIN')));
            $this->context->controller->addJS(($this->_path).'js/blockloginregister.js');
            $this->context->controller->addCSS(_PS_JS_DIR_.'jquery/plugins/fancybox/jquery.fancybox.css', 'all');
            $this->context->controller->addJS(_PS_JS_DIR_.'jquery/plugins/fancybox/jquery.fancybox.js');
        }
    }
}
